@@ -1,20 +1,16 @@
 """Models for the ``multilingual_events`` app."""
 from __future__ import unicode_literals
 
-from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import Q
 from django.utils import timezone
-from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
 from cms.models import CMSPlugin
+from cms.models.fields import PlaceholderField
 from django_countries import CountryField
-from django_libs.models_mixins import SimpleTranslationMixin
-from djangocms_utils.fields import M2MPlaceholderField
-from simple_translation.actions import SimpleTranslationPlaceholderActions
-from simple_translation.utils import get_preferred_translation_from_lang
+from hvad.models import TranslatedFields, TranslatableModel, TranslationManager
 
 from .settings import DISPLAY_TYPE_CHOICES
 
@@ -25,7 +21,7 @@ lat_lng_help_text = _(
     ' target="_blank">this website</a>')
 
 
-class EventCategory(SimpleTranslationMixin, models.Model):
+class EventCategory(TranslatableModel):
     """
     Events are grouped in categories.
 
@@ -44,26 +40,18 @@ class EventCategory(SimpleTranslationMixin, models.Model):
         verbose_name=_('Slug'),
     )
 
-    def __unicode__(self):
-        return self.get_translation().title
-
-
-class EventCategoryTitle(models.Model):
-    """
-    Translateable fields of the ``EventCategory`` model.
-
-    """
-    title = models.CharField(
-        max_length=256,
-        verbose_name=_('Title'),
+    translations = TranslatedFields(
+        title=models.CharField(
+            max_length=256,
+            verbose_name=_('Title'),
+        )
     )
 
-    # Needed by simple-translation
-    category = models.ForeignKey(EventCategory, verbose_name=_('Category'))
-    language = models.CharField(max_length=2, verbose_name=_('Language'))
+    def __unicode__(self):
+        return self.safe_translation_getter('title', self.slug)
 
 
-class EventManager(models.Manager):
+class EventManager(TranslationManager):
     """Custom manager for the ``Event`` model."""
     def get_archived(self, request):
         language = getattr(request, 'LANGUAGE_CODE', None)
@@ -72,8 +60,8 @@ class EventManager(models.Manager):
 
         qs = self.get_query_set()
         qs = qs.filter(
-            eventtitle__is_published=True,
-            eventtitle__language=language,
+            translations__is_published=True,
+            translations__language_code=language,
         )
         qs = qs.filter(
             Q(start_date__lt=timezone.now()) & (
@@ -87,8 +75,8 @@ class EventManager(models.Manager):
 
         qs = self.get_query_set()
         qs = qs.filter(
-            eventtitle__is_published=True,
-            eventtitle__language=language,
+            translations__is_published=True,
+            translations__language_code=language,
         )
         qs = qs.filter(
             Q(end_date__gte=timezone.now()) |
@@ -96,7 +84,7 @@ class EventManager(models.Manager):
         return qs.distinct()
 
 
-class Event(SimpleTranslationMixin, models.Model):
+class Event(TranslatableModel):
     """
     An event is something that happens on a specific start date.
 
@@ -108,9 +96,14 @@ class Event(SimpleTranslationMixin, models.Model):
 
     """
 
-    placeholders = M2MPlaceholderField(
-        actions=SimpleTranslationPlaceholderActions(),
-        placeholders=('conference', 'detailed_description'),
+    conference = PlaceholderField(
+        'multilingual_events_conference',
+        related_name='conference_events',
+    )
+
+    detailed_description = PlaceholderField(
+        'multilingual_events_detailed_description',
+        related_name='description_events',
     )
 
     # Allow null for once but remove this later, when data is setup.
@@ -192,31 +185,81 @@ class Event(SimpleTranslationMixin, models.Model):
         null=True, blank=True,
     )
 
+    translations = TranslatedFields(
+        title=models.CharField(
+            max_length=512,
+            verbose_name=_('Title'),
+        ),
+        venue_name=models.CharField(
+            max_length=256,
+            verbose_name=_('Venue name'),
+            blank=True,
+        ),
+        city=models.CharField(
+            max_length=256,
+            verbose_name=_('City'),
+            blank=True,
+        ),
+        postal_code=models.CharField(
+            max_length=256,
+            verbose_name=_('Postal code'),
+            blank=True,
+        ),
+        address_1=models.CharField(
+            max_length=256,
+            verbose_name=_('Address 1'),
+            blank=True,
+        ),
+        address_2=models.CharField(
+            max_length=256,
+            verbose_name=_('Address 2'),
+            blank=True,
+        ),
+        room=models.CharField(
+            max_length=256,
+            verbose_name=_('Block / Room'),
+            blank=True,
+        ),
+        description=models.TextField(
+            verbose_name=_('Description'),
+            blank=True,
+        ),
+        is_published=models.BooleanField(
+            default=False,
+            verbose_name=_('Is published'),
+        ),
+        meta_description=models.TextField(
+            max_length=512,
+            verbose_name=_('Meta description'),
+            blank=True,
+        )
+    )
+
     objects = EventManager()
 
     class Meta:
         ordering = ('start_date', )
 
     def __unicode__(self):
-        return self.get_title()
+        return self.safe_translation_getter('title', 'Event on the {0}'.format(
+            self.start_date))
 
     def get_absolute_url(self):
         return reverse('multilingual_events_detail', kwargs={'pk': self.pk})
 
     def get_address(self):
         """Returns the address with country."""
-        trans = self.get_translation()
         full_address = u''
-        if trans.venue_name:
-            full_address += u'{0}<br />'.format(trans.venue_name)
-        if trans.address_1:
-            full_address += u'{0}<br />'.format(trans.address_1)
-        if trans.address_2:
-            full_address += u'{0}<br />'.format(trans.address_2)
-        if trans.city:
-            if trans.postal_code:
-                full_address += u'{0} '.format(trans.postal_code)
-            full_address += u'{0}<br />'.format(trans.city)
+        if self.venue_name:
+            full_address += u'{0}<br />'.format(self.venue_name)
+        if self.address_1:
+            full_address += u'{0}<br />'.format(self.address_1)
+        if self.address_2:
+            full_address += u'{0}<br />'.format(self.address_2)
+        if self.city:
+            if self.postal_code:
+                full_address += u'{0} '.format(self.postal_code)
+            full_address += u'{0}<br />'.format(self.city)
         full_address += u'{0}'.format(unicode(self.country.name))
         return full_address
 
@@ -225,10 +268,9 @@ class Event(SimpleTranslationMixin, models.Model):
             pk=self.pk).order_by('start_date')
 
     def get_city_and_country(self):
-        trans = self.get_translation()
         result = u''
-        if trans.city:
-            result += u'{0}, '.format(trans.city)
+        if self.city:
+            result += u'{0}, '.format(self.city)
         result += unicode(self.country.name)
         return result
 
@@ -240,8 +282,7 @@ class Event(SimpleTranslationMixin, models.Model):
         return amount.days + 1
 
     def get_title(self):
-        lang = get_language()
-        return get_preferred_translation_from_lang(self, lang).title
+        return self.title
 
 
 class EventPluginModel(CMSPlugin):
@@ -266,104 +307,6 @@ class EventPluginModel(CMSPlugin):
         return '{} ({})'.format(self.event, self.event.category)
 
 
-class EventTitle(models.Model):
-    """
-    Translateable fields of the ``Event`` model.
-
-    :title: Title off the event.
-    :venue_name: The venue, this event takes place.
-    :city: The city the event will be in.
-    :postal_code: The postal code of the city:
-    :address_1: The address of the event.
-    :address_2: An additional address of the event.
-    :room: The room this event will be in.
-    :description: A description of the event
-    :is_published: If ``True``, the event would be returned by the
-      ``get_events`` templatetag.
-    :meta_description: The meta description to display for the detail page.
-
-    """
-    title = models.CharField(
-        max_length=512,
-        verbose_name=_('Title'),
-    )
-
-    venue_name = models.CharField(
-        max_length=256,
-        verbose_name=_('Venue name'),
-        blank=True,
-    )
-
-    city = models.CharField(
-        max_length=256,
-        verbose_name=_('City'),
-        blank=True,
-    )
-
-    postal_code = models.CharField(
-        max_length=256,
-        verbose_name=_('Postal code'),
-        blank=True,
-    )
-
-    address_1 = models.CharField(
-        max_length=256,
-        verbose_name=_('Address 1'),
-        blank=True,
-    )
-
-    address_2 = models.CharField(
-        max_length=256,
-        verbose_name=_('Address 2'),
-        blank=True,
-    )
-
-    room = models.CharField(
-        max_length=256,
-        verbose_name=_('Block / Room'),
-        blank=True,
-    )
-
-    description = models.TextField(
-        verbose_name=_('Description'),
-        blank=True,
-    )
-
-    is_published = models.BooleanField(
-        default=False,
-        verbose_name=_('Is published'),
-    )
-
-    meta_description = models.TextField(
-        max_length=512,
-        verbose_name=_('Meta description'),
-        blank=True,
-    )
-
-    # Needed by simple_translation
-    event = models.ForeignKey(Event, verbose_name=_('Event'))
-    language = models.CharField(max_length=5, verbose_name=('Language'))
-
-    def get_meta_description(self):
-        if self.meta_description:
-            return self.meta_description
-        if len(self.description) > 160:
-            return '{}...'.format(
-                self.description.replace('"', '&quot;')[:160])
-        return self.description.replace('"', '&quot;')
-
-    def get_absolute_url(self):
-        middleware = (
-            'simple_translation.middleware.MultilingualGenericsMiddleware')
-        language_namespace = middleware in settings.MIDDLEWARE_CLASSES \
-            and '%s:' % self.language or ''
-        return reverse(
-            '%smultilingual_events_detail' % language_namespace,
-            args=(),
-            kwargs={'pk': self.event.pk, }
-        )
-
-
 class EventAgendaDay(CMSPlugin):
     """The day and title of an event."""
     date = models.DateField(
